@@ -261,7 +261,9 @@ struct _ClutterActorClass
   gpointer _padding_dummy[28];
 };
 
-GType                 clutter_actor_get_type                  (void) G_GNUC_CONST;
+GType clutter_actor_get_type (void) G_GNUC_CONST;
+
+ClutterActor *        clutter_actor_new                       (void);
 
 void                  clutter_actor_set_flags                 (ClutterActor          *self,
                                                                ClutterActorFlags      flags);
@@ -280,6 +282,8 @@ void                  clutter_actor_unmap                     (ClutterActor
 void                  clutter_actor_paint                     (ClutterActor          *self);
 void                  clutter_actor_continue_paint            (ClutterActor          *self);
 void                  clutter_actor_queue_redraw              (ClutterActor          *self);
+void                  clutter_actor_queue_redraw_with_clip    (ClutterActor          *self,
+                                                               const cairo_rectangle_int_t *clip);
 
 void                  clutter_actor_queue_relayout            (ClutterActor          *self);
 void                  clutter_actor_destroy                   (ClutterActor          *self);
@@ -326,6 +330,7 @@ void                  clutter_actor_get_allocation_geometry   (ClutterActor
 void                  clutter_actor_get_allocation_vertices   (ClutterActor          *self,
 							       ClutterActor          *ancestor,
                                                                ClutterVertex          verts[]);
+gboolean              clutter_actor_has_allocation            (ClutterActor          *self);
 void                  clutter_actor_set_size                  (ClutterActor          *self,
                                                                gfloat                 width,
                                                                gfloat                 height);
@@ -348,7 +353,11 @@ void                  clutter_actor_get_transformed_position  (ClutterActor
 gboolean              clutter_actor_get_fixed_position_set    (ClutterActor          *self);
 void                  clutter_actor_set_fixed_position_set    (ClutterActor          *self,
                                                                gboolean               is_set);
+void                  clutter_actor_move_by                   (ClutterActor          *self,
+                                                               gfloat                 dx,
+                                                               gfloat                 dy);
 
+/* Actor geometry */
 gfloat                clutter_actor_get_width                 (ClutterActor          *self);
 gfloat                clutter_actor_get_height                (ClutterActor          *self);
 void                  clutter_actor_set_width                 (ClutterActor          *self,
@@ -361,21 +370,36 @@ void                  clutter_actor_set_x                     (ClutterActor
                                                                gfloat                 x);
 void                  clutter_actor_set_y                     (ClutterActor          *self,
                                                                gfloat                 y);
-void                  clutter_actor_set_rotation              (ClutterActor          *self,
-                                                               ClutterRotateAxis      axis,
-                                                               gdouble                angle,
-                                                               gfloat                 x,
-                                                               gfloat                 y,
-                                                               gfloat                 z);
-void                  clutter_actor_set_z_rotation_from_gravity (ClutterActor        *self,
-                                                               gdouble                angle,
-                                                               ClutterGravity         gravity);
-gdouble               clutter_actor_get_rotation              (ClutterActor          *self,
-                                                               ClutterRotateAxis      axis,
-                                                               gfloat                *x,
-                                                               gfloat                *y,
-                                                               gfloat                *z);
-ClutterGravity        clutter_actor_get_z_rotation_gravity    (ClutterActor          *self);
+void                  clutter_actor_set_depth                 (ClutterActor          *self,
+                                                               gfloat                 depth);
+gfloat                clutter_actor_get_depth                 (ClutterActor          *self);
+void                  clutter_actor_set_layout_manager        (ClutterActor          *self,
+                                                               ClutterLayoutManager  *manager);
+ClutterLayoutManager *clutter_actor_get_layout_manager        (ClutterActor          *self);
+
+void                  clutter_actor_set_x_align               (ClutterActor          *self,
+                                                               ClutterActorAlign      x_align);
+ClutterActorAlign     clutter_actor_get_x_align               (ClutterActor          *self);
+void                  clutter_actor_set_y_align               (ClutterActor          *self,
+                                                               ClutterActorAlign      y_align);
+ClutterActorAlign     clutter_actor_get_y_align               (ClutterActor          *self);
+
+void                  clutter_actor_set_margin_top            (ClutterActor          *self,
+                                                               gfloat                 margin);
+gfloat                clutter_actor_get_margin_top            (ClutterActor          *self);
+void                  clutter_actor_set_margin_bottom         (ClutterActor          *self,
+                                                               gfloat                 margin);
+gfloat                clutter_actor_get_margin_bottom         (ClutterActor          *self);
+void                  clutter_actor_set_margin_left           (ClutterActor          *self,
+                                                               gfloat                 margin);
+gfloat                clutter_actor_get_margin_left           (ClutterActor          *self);
+void                  clutter_actor_set_margin_right          (ClutterActor          *self,
+                                                               gfloat                 margin);
+gfloat                clutter_actor_get_margin_right          (ClutterActor          *self);
+void                  clutter_actor_set_margin                (ClutterActor          *self,
+                                                               const ClutterMargin   *margin);
+void                  clutter_actor_get_margin                (ClutterActor          *self,
+                                                               ClutterMargin         *margin);
 
 void                  clutter_actor_set_opacity               (ClutterActor          *self,
                                                                guint8                 opacity);
@@ -409,25 +433,74 @@ void                  clutter_actor_set_clip_to_allocation    (ClutterActor
                                                                gboolean               clip_set);
 gboolean              clutter_actor_get_clip_to_allocation    (ClutterActor          *self);
 
-void                  clutter_actor_set_parent                (ClutterActor          *self,
-                                                               ClutterActor          *parent);
+/* Events */
+void                  clutter_actor_set_reactive              (ClutterActor          *actor,
+                                                               gboolean               reactive);
+gboolean              clutter_actor_get_reactive              (ClutterActor          *actor);
+gboolean              clutter_actor_has_key_focus             (ClutterActor          *self);
+void                  clutter_actor_grab_key_focus            (ClutterActor          *self);
+gboolean              clutter_actor_event                     (ClutterActor          *actor,
+                                                               ClutterEvent          *event,
+                                                               gboolean               capture);
+
+/* Actor hierarchy */
+void                  clutter_actor_add_child                 (ClutterActor          *self,
+                                                               ClutterActor          *child);
+void                  clutter_actor_insert_child_at_index     (ClutterActor          *self,
+                                                               ClutterActor          *child,
+                                                               gint                   index_);
+void                  clutter_actor_insert_child_above        (ClutterActor          *self,
+                                                               ClutterActor          *child,
+                                                               ClutterActor          *sibling);
+void                  clutter_actor_insert_child_below        (ClutterActor          *self,
+                                                               ClutterActor          *child,
+                                                               ClutterActor          *sibling);
+void                  clutter_actor_replace_child             (ClutterActor          *self,
+                                                               ClutterActor          *old_child,
+                                                               ClutterActor          *new_child);
+void                  clutter_actor_remove_child              (ClutterActor          *self,
+                                                               ClutterActor          *child);
+void                  clutter_actor_remove_all_children       (ClutterActor          *self);
+GList *               clutter_actor_get_children              (ClutterActor          *self);
+gint                  clutter_actor_get_n_children            (ClutterActor          *self);
+ClutterActor *        clutter_actor_get_child_at_index        (ClutterActor          *self,
+                                                               gint                   index_);
+ClutterActor *        clutter_actor_get_previous_sibling      (ClutterActor          *self);
+ClutterActor *        clutter_actor_get_next_sibling          (ClutterActor          *self);
+ClutterActor *        clutter_actor_get_first_child           (ClutterActor          *self);
+ClutterActor *        clutter_actor_get_last_child            (ClutterActor          *self);
 ClutterActor *        clutter_actor_get_parent                (ClutterActor          *self);
-void                  clutter_actor_reparent                  (ClutterActor          *self,
-                                                               ClutterActor          *new_parent);
-void                  clutter_actor_unparent                  (ClutterActor          *self);
 gboolean              clutter_actor_contains                  (ClutterActor          *self,
 							       ClutterActor          *descendant);
 ClutterActor*         clutter_actor_get_stage                 (ClutterActor          *actor);
+void                  clutter_actor_set_child_below_sibling   (ClutterActor          *self,
+                                                               ClutterActor          *child,
+                                                               ClutterActor          *sibling);
+void                  clutter_actor_set_child_above_sibling   (ClutterActor          *self,
+                                                               ClutterActor          *child,
+                                                               ClutterActor          *sibling);
+void                  clutter_actor_set_child_at_index        (ClutterActor          *self,
+                                                               ClutterActor          *child,
+                                                               gint                   index_);
 
-void                  clutter_actor_raise                     (ClutterActor          *self,
-                                                               ClutterActor          *below);
-void                  clutter_actor_lower                     (ClutterActor          *self,
-                                                               ClutterActor          *above);
-void                  clutter_actor_raise_top                 (ClutterActor          *self);
-void                  clutter_actor_lower_bottom              (ClutterActor          *self);
-void                  clutter_actor_set_depth                 (ClutterActor          *self,
-                                                               gfloat                 depth);
-gfloat                clutter_actor_get_depth                 (ClutterActor          *self);
+/* Transformations */
+gboolean              clutter_actor_is_rotated                (ClutterActor          *self);
+gboolean              clutter_actor_is_scaled                 (ClutterActor          *self);
+void                  clutter_actor_set_rotation              (ClutterActor          *self,
+                                                               ClutterRotateAxis      axis,
+                                                               gdouble                angle,
+                                                               gfloat                 x,
+                                                               gfloat                 y,
+                                                               gfloat                 z);
+void                  clutter_actor_set_z_rotation_from_gravity (ClutterActor        *self,
+                                                               gdouble                angle,
+                                                               ClutterGravity         gravity);
+gdouble               clutter_actor_get_rotation              (ClutterActor          *self,
+                                                               ClutterRotateAxis      axis,
+                                                               gfloat                *x,
+                                                               gfloat                *y,
+                                                               gfloat                *z);
+ClutterGravity        clutter_actor_get_z_rotation_gravity    (ClutterActor          *self);
 
 void                  clutter_actor_set_scale                 (ClutterActor          *self,
                                                                gdouble                scale_x,
@@ -448,41 +521,26 @@ void                  clutter_actor_get_scale_center          (ClutterActor
                                                                gfloat                *center_x,
                                                                gfloat                *center_y);
 ClutterGravity        clutter_actor_get_scale_gravity         (ClutterActor          *self);
-
-void                  clutter_actor_move_by                   (ClutterActor          *self,
-                                                               gfloat                 dx,
-                                                               gfloat                 dy);
-
-void                  clutter_actor_set_reactive              (ClutterActor          *actor,
-                                                               gboolean               reactive);
-gboolean              clutter_actor_get_reactive              (ClutterActor          *actor);
-
-gboolean              clutter_actor_event                     (ClutterActor          *actor,
-                                                               ClutterEvent          *event,
-                                                               gboolean               capture);
-
-void     clutter_actor_set_anchor_point               (ClutterActor   *self,
-                                                       gfloat          anchor_x,
-                                                       gfloat          anchor_y);
-void     clutter_actor_move_anchor_point              (ClutterActor   *self,
-                                                       gfloat          anchor_x,
-                                                       gfloat          anchor_y);
-void     clutter_actor_get_anchor_point               (ClutterActor   *self,
-                                                       gfloat         *anchor_x,
-                                                       gfloat         *anchor_y);
-ClutterGravity clutter_actor_get_anchor_point_gravity (ClutterActor   *self);
-void     clutter_actor_set_anchor_point_from_gravity  (ClutterActor   *self,
-                                                       ClutterGravity  gravity);
-void     clutter_actor_move_anchor_point_from_gravity (ClutterActor   *self,
-                                                       ClutterGravity  gravity);
+void                  clutter_actor_set_anchor_point          (ClutterActor          *self,
+                                                               gfloat                 anchor_x,
+                                                               gfloat                 anchor_y);
+void                  clutter_actor_move_anchor_point         (ClutterActor          *self,
+                                                               gfloat                 anchor_x,
+                                                               gfloat                 anchor_y);
+void                  clutter_actor_get_anchor_point          (ClutterActor          *self,
+                                                               gfloat                *anchor_x,
+                                                               gfloat                *anchor_y);
+ClutterGravity        clutter_actor_get_anchor_point_gravity  (ClutterActor          *self);
+void                  clutter_actor_set_anchor_point_from_gravity  (ClutterActor     *self,
+                                                               ClutterGravity         gravity);
+void                  clutter_actor_move_anchor_point_from_gravity (ClutterActor     *self,
+                                                               ClutterGravity         gravity);
 
 gboolean clutter_actor_transform_stage_point          (ClutterActor   *self,
                                                        gfloat          x,
                                                        gfloat          y,
                                                        gfloat         *x_out,
                                                        gfloat         *y_out);
-gboolean clutter_actor_is_rotated                     (ClutterActor   *self);
-gboolean clutter_actor_is_scaled                      (ClutterActor   *self);
 gboolean clutter_actor_should_pick_paint              (ClutterActor   *self);
 
 void clutter_actor_get_abs_allocation_vertices        (ClutterActor        *self,
@@ -496,8 +554,6 @@ void clutter_actor_apply_relative_transform_to_point  (ClutterActor        *self
                                                        const ClutterVertex *point,
                                                        ClutterVertex       *vertex);
 
-void          clutter_actor_grab_key_focus            (ClutterActor        *self);
-
 PangoContext *clutter_actor_get_pango_context         (ClutterActor        *self);
 PangoContext *clutter_actor_create_pango_context      (ClutterActor        *self);
 PangoLayout * clutter_actor_create_pango_layout       (ClutterActor        *self,
@@ -513,15 +569,8 @@ void                 clutter_actor_set_text_direction (ClutterActor         *sel
                                                        ClutterTextDirection  text_dir);
 ClutterTextDirection clutter_actor_get_text_direction (ClutterActor         *self);
 
-void                 clutter_actor_push_internal      (ClutterActor         *self);
-void                 clutter_actor_pop_internal       (ClutterActor         *self);
-
-gboolean             clutter_actor_has_allocation     (ClutterActor         *self);
-
 AtkObject *          clutter_actor_get_accessible     (ClutterActor         *self);
 
-gboolean             clutter_actor_has_key_focus      (ClutterActor         *self);
-
 const ClutterPaintVolume  *clutter_actor_get_paint_volume             (ClutterActor         *self);
 const ClutterPaintVolume  *clutter_actor_get_transformed_paint_volume (ClutterActor *self,
                                                                        ClutterActor *relative_to_ancestor);
@@ -531,6 +580,11 @@ gboolean             clutter_actor_get_paint_box      (ClutterActor         *sel
 
 gboolean             clutter_actor_has_overlaps       (ClutterActor         *self);
 
+void                    clutter_actor_set_background_color      (ClutterActor       *self,
+                                                                 const ClutterColor *color);
+void                    clutter_actor_get_background_color      (ClutterActor       *self,
+                                                                 ClutterColor       *color);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_ACTOR_H__ */
